#
# spec file for package libdvdnav
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   4
Name:           libdvdnav
Version:        6.1.1
Release:        150600.1.1
Summary:        DVD Navigation Library
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://www.videolan.org/developers/libdvdnav.html
Source0:        https://download.videolan.org/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        https://download.videolan.org/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source1000:     baselibs.conf
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dvdread) >= 6.0.0

%description
This library contains functions to display DVD video menus.

%package -n libdvdnav%{sover}
Summary:        A DVD Navigation Library
Group:          Productivity/Multimedia/Other
Provides:       %{name}
Obsoletes:      %{name}

%description -n libdvdnav%{sover}
This library contains functions to display DVD video menus.

%package devel
Summary:        Development Environment for libdvdnav
Group:          Development/Libraries/C and C++
Requires:       libdvdnav%{sover} = %{version}

%description devel
This library contains functions to display DVD video menus.

%prep
%autosetup

%build
autoreconf -fvi
%configure \
  --disable-silent-rules \
  --disable-static
%make_build

%install
%make_install
rm -r %{buildroot}%{_datadir}/doc/libdvdnav/
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libdvdnav%{sover} -p /sbin/ldconfig
%postun -n libdvdnav%{sover} -p /sbin/ldconfig

%files -n libdvdnav%{sover}
%{_libdir}/libdvdnav.so.%{sover}
%{_libdir}/libdvdnav.so.%{sover}.*
%license COPYING
%doc AUTHORS ChangeLog README TODO

%files devel
%{_includedir}/dvdnav
%{_libdir}/libdvdnav.so
%{_libdir}/pkgconfig/dvdnav.pc

%changelog
* Sun May  9 2021 dmueller@suse.com
- update to 6.1.1:
  * fix build issues
  * improve CI
* Mon Apr 27 2020 aloisio@gmx.com
- Update to version 6.1.0
  * add a dvdnav_open2 API to setup a logging mechanism, similar
    to libdvdread
  * add a dvdnav_get_number_of_angles API
  * add a dvdnav_version API
  * rework the logs in the library and remove direct printf calls
  * handle out-of-order ADMAP entries blocking playback
  * fix crashes in dvdnav_describe_title_chapters in broken DVDs
  * cleanup old code and buildsystem
- Added libdvdnav.keyring as source and enabled signature file
- Dropped libdvdnav-dvdread.patch (no longer necessary)
- Spec cleanup
* Thu Oct 17 2019 enzokiel@kabelmail.de
- Update to version 6.0.1:
  * improve random playback mode, to work-around broken discs
  * fix divide-by-zerop issue in tmap search
  * fix pthread on OS/2
- Removed gpg signature (not available)
* Wed Aug 14 2019 tchvatal@suse.com
- Format with spec-cleaner
- Remove not really needed patch:
  * libdvdnav-strict-aliasing.patch
* Mon Apr 15 2019 olaf@aepfle.de
- Point URL to videolan.org
* Sat Jan 27 2018 j.lorenzen@kabelmail.de
- Update to version 6.0.0:
  * fix crashes on some DVD on describe_title call
  * fix various crashes related to PGC validity
  * fix compilation issues
  * fix API return codes
- Add gpg signature
* Tue Aug 30 2016 olaf@aepfle.de
- BuildRequire dvdread >= 5.0.2
  libdvdnav-dvdread.patch
* Fri Feb  6 2015 joerg.lorenzen@ki.tng.de
- Update to version 5.0.3:
  + added dvdnav_open_stream to read from external read/seek callbacks
  + fixed reading DVD label regression
* Mon Jan 26 2015 joerg.lorenzen@ki.tng.de
- Update to version 5.0.2:
  + fixed 2 wrong asserts (lp#1236939, lp#570790)
  + fixed 2 crashes (in dvdnav_get_position and dvdnav_get_position
  _in_title)
* Wed Dec 17 2014 joerg.lorenzen@ki.tng.de
- Update to version 5.0.1:
  + removed assert on unknown VM commands, fixing playback of
    some DVDs
  + fixed a double free in dvdnav_free_dup
  + fixed an integer overflow, a data race condition and return
    inconsistency
- Version 5.0.0:
  + Android support
  + fixed numerous crashes, assertions and corruptions
  + rewrite of the build-system, including silent rules
  + clean code, simplify and remove warnings
  + fix compilation in C++ applications
  + removal of remap .MAP files unused feature
  + remove the dvdnavmini library
  + fix compilation on OS/2 and Hurd
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 4.2.1:
  + Fixed failed assertion on menu-less DVDs.
  + Fixed playback issues on multi-angle DVDs.
  + Fixed crash when playing a DVD from different region than
    currently set in the DVD drive.
  + Fixed segfaults when reading certain DVDs (including "Jack
    Reacher", "Ghost Protocol", "Inside Man", "Tangled" and
    "The Dictator").
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 4.2.0:
  * added dvdnav_get_serial_string() function
  * fixed ifo leak in dvdnav_describe_chapters()
  * added dvdnav_get_video_resolution() to retrieve video resolution
  * added dvdnav_program_play() & dvdnav_current_title_program() for
    more reliable playback
  * fixed deadlock between dvdnav_reset() and dvd_clear()
  * fixed pthread_mutex_destroy macro for Win32
  * fixed numerous assertion failures occuring when playing DVDs with
    new "copy protection" schemes
  * fixed forward seeks to always move forward
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Thu Jan 27 2011 davejplater@gmail.com
- Added Requires: pkg-config to get the .pc file to build.
* Fri Nov 20 2009 crrodriguez@opensuse.org
- libdvdnav4-4.1.3 contains libdvdnav.so.4.1.2 binaries  [bnc#503753]
* Wed Sep 10 2008 hvogel@suse.de
- update to 4.1.3
  * fixes regarding potential memory and resource leaks
  * added pkg-config support
- branch library subpackage
* Tue Jul  1 2008 hvogel@suse.de
- update to version 4.1.2, switching to version from mplayerhq
  * multiple build system fixes
  * added dvdnav_describe_title_chapters(title) to get title
    and chapters duration
  * added dvdnav_audio_stream_channels() to return number
    of channels
  * fixed dvdnav_time_search() in multi-angle dvds (but it still
    needs improvements)
  * added dvdnav_audio_stream_format() to identify the codec used
    in audio streams
  * starting DVD playback at specific title/part positions with
    dvdnav_{title,part}_play() works again
  * fixed error "Expected NAV packet but none found." occuring
    sometimes on resume from menu
* Wed Jan 10 2007 hvogel@suse.de
- fix possible strncat overflow
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  2 2005 hvogel@suse.de
- add -fno-strict-aliasing to CFLAGS
* Fri Sep  3 2004 hvogel@suse.de
- update to version 0.1.10
* Mon Jan 12 2004 adrian@suse.de
- fix build
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Thu Oct 23 2003 stepan@suse.de
- update to 0.1.9, needed by gnome 2.4
* Sun Jun  1 2003 ro@suse.de
- add aclocal file to devel filelist
* Fri Feb 14 2003 stepan@suse.de
- update to v0.1.4, needed by vdr-plugins
* Sun Feb  2 2003 adrian@suse.de
- fix requires
* Sat Nov  2 2002 stepan@suse.de
- include dvdnavconfig (needed by MPlayer et al)
* Mon Oct 21 2002 stepan@suse.de
- initial release
